/*
 * (C) Copyright IBM Corporation 2006, 2015.
*/
/*
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
 the Free Software Foundation; either version 2, or (at your option)
 any later version.

 This program is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.

 You should have received a copy of the GNU General Public License
 along with this program; if not, write to the Free Software
 Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA

 Author: IBM Corporation and/or HCL Technologies Ltd.
 This module is part of the IBM (R) Rational (R) ClearCase (R)(*)
 Multi-version file system (MVFS).
 For support, please visit http://www.ibm.com/software/support

 * ClearCase is a trademark of IBM Corporation, registered in many
   jurisdictions, and is used under license.
*/
#ifndef MVFS_VFSOPS_H_
#define MVFS_VFSOPS_H_

#include "mvfs_base.h"

/* mvfs_vfs_get_datap
 * Returns a pointer to the corresponding vfs data structure for the given
 * vnode. This function always returns a valid pointer.
 *
 * Inputs:
 * vp - The vnode to retrieve the vfs data for.
 *
 * Returns:
 * A pointer to the vfs data corresponding to the given vnode or a pointer to
 * the global vfs data structure if vp is NULL.
 *
 */
extern mvfs_vfs_data_t *
mvfs_vfs_get_datap(VNODE_T *vp);

/* mvfs_vfs_data_init_flags_t
 * This defines a type to use as a flag value when calling mvfs_vfs_data_init.
 * It is needed because all the information necessary to fully initialize a vfs
 * data structure may not be setup when calling mvfs_vfs_data_init (the minor
 * map, namely).
 */
typedef unsigned int mvfs_vfs_data_init_flags_t;
#define MVFS_VDIF_LOCK 0x1 /* Mount lock */
#define MVFS_VDIF_VOB_MOUNTS 0x2 /* Vob mounts */
#define MVFS_VDIF_VMD 0x4 /* Various mount data (mount_count, etc) */
#define MVFS_VDIF_ALL (MVFS_VDIF_LOCK | MVFS_VDIF_VOB_MOUNTS | MVFS_VDIF_VMD)

/* mvfs_vfs_data_init
 * Initializes the given mvfs_vfs_data structure.  The mount_lock within
 * the structure is initialized using the given tag.  The name of the lock is of
 * the form "mount_lock [tag]".
 *
 * Inputs:
 * mvdif - A flag value specifying the members to initialize.
 * mvdp - The mvfs_vfs_data structure to initialized.
 * mount_lock_tag - A string containing the desired mvfs_mountlock tag.
 *
 * Returns:
 * Non-zero if an error occurs, zero otherwise.
 */
extern int
mvfs_vfs_data_init(
    mvfs_vfs_data_init_flags_t mif,
    mvfs_vfs_data_t *mvdp,
    const char *mount_lock_tag
);

/* mvfs_vfs_data_clean
 * Cleans the given mvfs_vfs_data structure, freeing the mount_lock and vob
 * mount table (if necessary).
 *
 * Inputs:
 * mvdp - The mvfs_vfs_data structure to clean.
 *
 * Returns:
 * void
 */
extern void
mvfs_vfs_data_clean(mvfs_vfs_data_t *mvdp);

#endif /* MVFS_VFSOPS_H_ */
/* $Id: 92ae499b.888f11e5.890f.00:01:84:c3:8a:52 $ */
